# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import ros_pb2 as protos_dot_model_dot_v1_dot_ros__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/config.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cprotos/model/v1/config.proto\x12\x08v1.model\x1a\x19protos/model/v1/ros.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xbe\x01\n\x17\x41gentConfigurationStore\x12#\n\ragent_version\x18\x01 \x01(\tR\x0c\x61gentVersion\x12\x42\n\rconfiguration\x18\x02 \x01(\x0b\x32\x1c.v1.model.AgentConfigurationR\rconfiguration\x12:\n\x0b\x66\x65\x61ture_set\x18\x03 \x01(\x0b\x32\x19.v1.model.AgentFeatureSetR\nfeatureSet\"\xa2\x03\n\x0f\x41gentFeatureSet\x12\x1c\n\ttelemetry\x18\x01 \x01(\x08R\ttelemetry\x12-\n\x12internal_telemetry\x18\x02 \x01(\x08R\x11internalTelemetry\x12\x16\n\x06teleop\x18\x03 \x01(\x08R\x06teleop\x12#\n\rcustom_events\x18\x04 \x01(\x08R\x0c\x63ustomEvents\x12)\n\x10triggered_events\x18\x05 \x01(\x08R\x0ftriggeredEvents\x12\x10\n\x03ssh\x18\x06 \x01(\x08R\x03ssh\x12\'\n\x0fport_forwarding\x18\x07 \x01(\x08R\x0eportForwarding\x12\x1a\n\x08\x63ommands\x18\x08 \x01(\x08R\x08\x63ommands\x12$\n\rinterventions\x18\t \x01(\x08R\rinterventions\x12\x1b\n\ton_demand\x18\n \x01(\x08R\x08onDemand\x12\x1d\n\napp_config\x18\x0b \x01(\x08R\tappConfig\x12!\n\x0c\x62lob_storage\x18\x0c \x01(\x08R\x0b\x62lobStorage\"z\n\x12\x41gentConfiguration\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12@\n\x08\x64ocument\x18\x03 \x01(\x0b\x32$.v1.model.AgentConfigurationDocumentR\x08\x64ocument\"\x99\x06\n\x1a\x41gentConfigurationDocument\x12\x18\n\x07version\x18\x01 \x01(\x03R\x07version\x12\x42\n\x04tags\x18\x02 \x03(\x0b\x32..v1.model.AgentConfigurationDocument.TagsEntryR\x04tags\x12>\n\ttelemetry\x18\x03 \x01(\x0b\x32 .v1.model.TelemetryConfigurationR\ttelemetry\x12>\n\tresources\x18\x04 \x01(\x0b\x32 .v1.model.ResourcesConfigurationR\tresources\x12\x44\n\x0b\x61pplication\x18\x05 \x01(\x0b\x32\".v1.model.ApplicationConfigurationR\x0b\x61pplication\x12\x35\n\x06teleop\x18\x06 \x01(\x0b\x32\x1d.v1.model.TeleopConfigurationR\x06teleop\x12N\n\x0fport_forwarding\x18\x07 \x01(\x0b\x32%.v1.model.PortForwardingConfigurationR\x0eportForwarding\x12/\n\tblob_data\x18\x08 \x01(\x0b\x32\x12.v1.model.BlobDataR\x08\x62lobData\x12\x37\n\x0b\x64iagnostics\x18\t \x01(\x0b\x32\x15.v1.model.DiagnosticsR\x0b\x64iagnostics\x12\x43\n\x0fterminal_access\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0eterminalAccess\x12:\n\x08\x61\x64\x61pters\x18\x0b \x03(\x0b\x32\x1e.v1.model.AdapterConfigurationR\x08\x61\x64\x61pters\x12,\n\x08rtc_info\x18\x0c \x01(\x0b\x32\x11.v1.model.RtcInfoR\x07rtcInfo\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"v\n\x14\x41\x64\x61pterConfiguration\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x66ile_id\x18\x03 \x01(\tR\x06\x66ileId\x12!\n\x0c\x65xec_command\x18\x04 \x01(\tR\x0b\x65xecCommand\"\x88\x02\n\x13TeleopConfiguration\x12G\n\x0bros_streams\x18\x01 \x03(\x0b\x32&.v1.model.TeleopRosStreamConfigurationR\nrosStreams\x12P\n\x0e\x63ustom_streams\x18\x02 \x03(\x0b\x32).v1.model.TeleopCustomStreamConfigurationR\rcustomStreams\x12V\n\x10hardware_streams\x18\x03 \x03(\x0b\x32+.v1.model.TeleopHardwareStreamConfigurationR\x0fhardwareStreams\"S\n\x1bPortForwardingConfiguration\x12\x34\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x07\x65nabled\"\xcf\x02\n\x1cTeleopRosStreamConfiguration\x12\x1d\n\ntopic_name\x18\x01 \x01(\tR\ttopicName\x12\x35\n\ntopic_type\x18\x02 \x01(\x0e\x32\x16.v1.model.ROSTopicTypeR\ttopicType\x12(\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopModeR\x04mode\x12!\n\x0c\x65ncode_video\x18\x04 \x01(\x08R\x0b\x65ncodeVideo\x12\x1f\n\x0b\x61udio_codec\x18\x05 \x01(\tR\naudioCodec\x12\x18\n\x07quality\x18\x06 \x01(\tR\x07quality\x12\x30\n\x14\x62\x61se_reference_frame\x18\x07 \x01(\tR\x12\x62\x61seReferenceFrame\x12\x1f\n\x0blocal_frame\x18\x08 \x01(\tR\nlocalFrame\"\x8a\x03\n!TeleopHardwareStreamConfiguration\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12&\n\x0frtc_stream_type\x18\x02 \x01(\tR\rrtcStreamType\x12(\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopModeR\x04mode\x12#\n\rhw_descriptor\x18\x04 \x01(\tR\x0chwDescriptor\x12\x18\n\x07quality\x18\x05 \x01(\tR\x07quality\x12#\n\rhardware_type\x18\x06 \x01(\tR\x0chardwareType\x12\x30\n\x14rtsp_encoding_needed\x18\x07 \x01(\x08R\x12rtspEncodingNeeded\x12\x19\n\x08is_onvif\x18\x08 \x01(\x08R\x07isOnvif\x12&\n\x0fip_cam_username\x18\t \x01(\tR\ripCamUsername\x12&\n\x0fip_cam_password\x18\n \x01(\tR\ripCamPassword\"\xc4\x01\n\x1fTeleopCustomStreamConfiguration\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12&\n\x0frtc_stream_type\x18\x02 \x01(\tR\rrtcStreamType\x12(\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopModeR\x04mode\x12!\n\x0c\x65ncode_video\x18\x04 \x01(\x08R\x0b\x65ncodeVideo\x12\x18\n\x07quality\x18\x05 \x01(\tR\x07quality\"\x7f\n\x16TelemetryConfiguration\x12\x37\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.v1.model.StreamConfigurationR\x07streams\x12,\n\x03ros\x18\x02 \x01(\x0b\x32\x1a.v1.model.ROSConfigurationR\x03ros\"\xc6\x01\n\x18\x41pplicationConfiguration\x12\x65\n\x11\x63onfiguration_map\x18\x01 \x03(\x0b\x32\x38.v1.model.ApplicationConfiguration.ConfigurationMapEntryR\x10\x63onfigurationMap\x1a\x43\n\x15\x43onfigurationMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc5\x01\n\x16ResourcesConfiguration\x12/\n\x04\x64isk\x18\x01 \x01(\x0b\x32\x1b.v1.model.DiskConfigurationR\x04\x64isk\x12J\n\x12stream_throttle_hz\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x10streamThrottleHz\x12.\n\x13low_bandwidth_agent\x18\x03 \x01(\x08R\x11lowBandwidthAgent\"g\n\x11\x44iskConfiguration\x12\x1f\n\x0b\x62uffer_size\x18\x01 \x01(\x03R\nbufferSize\x12\x31\n\x15on_demand_buffer_size\x18\x02 \x01(\x03R\x12onDemandBufferSize\"K\n\x10ROSConfiguration\x12\x37\n\x18world_reference_frame_id\x18\x01 \x01(\tR\x15worldReferenceFrameId\"\xdd\x06\n\x13StreamConfiguration\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\x04tags\x18\x02 \x03(\x0b\x32\'.v1.model.StreamConfiguration.TagsEntryR\x04tags\x12\x31\n\tros_topic\x18\x03 \x01(\x0b\x32\x12.v1.model.ROSTopicH\x00R\x08rosTopic\x12\x46\n\x10ros_localization\x18\x04 \x01(\x0b\x32\x19.v1.model.ROSLocalizationH\x00R\x0frosLocalization\x12\x43\n\x0f\x64irectory_watch\x18\x05 \x01(\x0b\x32\x18.v1.model.DirectoryWatchH\x00R\x0e\x64irectoryWatch\x12\x31\n\tfile_tail\x18\x06 \x01(\x0b\x32\x12.v1.model.FileTailH\x00R\x08\x66ileTail\x12J\n\x12ros_transform_tree\x18\x07 \x01(\x0b\x32\x1a.v1.model.ROSTransformTreeH\x00R\x10rosTransformTree\x12*\n\x06\x63ustom\x18\t \x01(\x0b\x32\x10.v1.model.CustomH\x00R\x06\x63ustom\x12\x30\n\x08hardware\x18\n \x01(\x0b\x32\x12.v1.model.HardwareH\x00R\x08hardware\x12=\n\x0bthrottle_hz\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\nthrottleHz\x12\x36\n\x08\x64isabled\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x08\x64isabled\x12\x37\n\ton_demand\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x08onDemand\x12\x44\n\ttransform\x18\x15 \x01(\x0b\x32&.v1.model.StreamTransformConfigurationR\ttransform\x12\x18\n\x07quality\x18\x16 \x01(\tR\x07quality\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\rconfiguration\"p\n\x1cStreamTransformConfiguration\x12P\n\x16video_encoding_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x14videoEncodingEnabled\"\x1e\n\x08\x42lobData\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\tR\x04\x64\x61ta\"\x8d\x01\n\x0b\x44iagnostics\x12;\n\x0breport_logs\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\nreportLogs\x12\x41\n\x0ereport_metrics\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\rreportMetrics\"\x08\n\x06\x43ustom\"\xa1\x02\n\x08Hardware\x12#\n\rhw_descriptor\x18\x01 \x01(\tR\x0chwDescriptor\x12.\n\x13\x61udio_hw_descriptor\x18\x03 \x01(\tR\x11\x61udioHwDescriptor\x12#\n\rhardware_type\x18\x04 \x01(\tR\x0chardwareType\x12\x30\n\x14rtsp_encoding_needed\x18\x05 \x01(\x08R\x12rtspEncodingNeeded\x12\x19\n\x08is_onvif\x18\x06 \x01(\x08R\x07isOnvif\x12&\n\x0fip_cam_username\x18\x07 \x01(\tR\ripCamUsername\x12&\n\x0fip_cam_password\x18\x08 \x01(\tR\ripCamPassword\"\xa0\x01\n\x0e\x44irectoryWatch\x12\x1c\n\tdirectory\x18\x01 \x01(\tR\tdirectory\x12\x1c\n\textension\x18\x02 \x01(\tR\textension\x12/\n\tfile_type\x18\x03 \x01(\x0e\x32\x12.v1.model.FileTypeR\x08\x66ileType\x12!\n\x0cremote_agent\x18\x04 \x01(\x08R\x0bremoteAgent\"\xaf\x01\n\x08\x46ileTail\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x35\n\x0b\x66ile_format\x18\x02 \x01(\x0e\x32\x14.v1.model.FileFormatR\nfileFormat\x12\x19\n\x08time_key\x18\x03 \x01(\tR\x07timeKey\x12\x1f\n\x0btime_format\x18\x04 \x01(\tR\ntimeFormat\x12\x14\n\x05regex\x18\x05 \x01(\tR\x05regex\"\xa5\x01\n\x07RtcInfo\x12;\n\x1artc_ice_transport_policies\x18\x01 \x03(\tR\x17rtcIceTransportPolicies\x12\x35\n\x17rtc_ice_server_protocol\x18\x02 \x01(\tR\x14rtcIceServerProtocol\x12&\n\x0fuse_all_servers\x18\x03 \x01(\x08R\ruseAllServers*&\n\nTeleopMode\x12\x0b\n\x07\x43OMMAND\x10\x00\x12\x0b\n\x07OBSERVE\x10\x01*&\n\nFileFormat\x12\x0e\n\nPLAIN_TEXT\x10\x00\x12\x08\n\x04JSON\x10\x01*;\n\x08\x46ileType\x12\x08\n\x04\x46ILE\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\x0f\n\x0bPOINT_CLOUD\x10\x04\x12\t\n\x05VIDEO\x10\x05\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[protos_dot_model_dot_v1_dot_ros__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_TELEOPMODE = _descriptor.EnumDescriptor(
  name='TeleopMode',
  full_name='v1.model.TeleopMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMAND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSERVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5718,
  serialized_end=5756,
)
_sym_db.RegisterEnumDescriptor(_TELEOPMODE)

TeleopMode = enum_type_wrapper.EnumTypeWrapper(_TELEOPMODE)
_FILEFORMAT = _descriptor.EnumDescriptor(
  name='FileFormat',
  full_name='v1.model.FileFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PLAIN_TEXT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5758,
  serialized_end=5796,
)
_sym_db.RegisterEnumDescriptor(_FILEFORMAT)

FileFormat = enum_type_wrapper.EnumTypeWrapper(_FILEFORMAT)
_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='v1.model.FileType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT_CLOUD', index=2, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=3, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5798,
  serialized_end=5857,
)
_sym_db.RegisterEnumDescriptor(_FILETYPE)

FileType = enum_type_wrapper.EnumTypeWrapper(_FILETYPE)
COMMAND = 0
OBSERVE = 1
PLAIN_TEXT = 0
JSON = 1
FILE = 0
IMAGE = 1
POINT_CLOUD = 4
VIDEO = 5



_AGENTCONFIGURATIONSTORE = _descriptor.Descriptor(
  name='AgentConfigurationStore',
  full_name='v1.model.AgentConfigurationStore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_version', full_name='v1.model.AgentConfigurationStore.agent_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='agentVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='v1.model.AgentConfigurationStore.configuration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='configuration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='v1.model.AgentConfigurationStore.feature_set', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureSet', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=292,
)


_AGENTFEATURESET = _descriptor.Descriptor(
  name='AgentFeatureSet',
  full_name='v1.model.AgentFeatureSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='v1.model.AgentFeatureSet.telemetry', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='telemetry', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_telemetry', full_name='v1.model.AgentFeatureSet.internal_telemetry', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internalTelemetry', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teleop', full_name='v1.model.AgentFeatureSet.teleop', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='teleop', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_events', full_name='v1.model.AgentFeatureSet.custom_events', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='customEvents', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggered_events', full_name='v1.model.AgentFeatureSet.triggered_events', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='triggeredEvents', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssh', full_name='v1.model.AgentFeatureSet.ssh', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ssh', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_forwarding', full_name='v1.model.AgentFeatureSet.port_forwarding', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='portForwarding', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commands', full_name='v1.model.AgentFeatureSet.commands', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commands', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interventions', full_name='v1.model.AgentFeatureSet.interventions', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='interventions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand', full_name='v1.model.AgentFeatureSet.on_demand', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onDemand', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_config', full_name='v1.model.AgentFeatureSet.app_config', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='appConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blob_storage', full_name='v1.model.AgentFeatureSet.blob_storage', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='blobStorage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=713,
)


_AGENTCONFIGURATION = _descriptor.Descriptor(
  name='AgentConfiguration',
  full_name='v1.model.AgentConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.AgentConfiguration.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.AgentConfiguration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document', full_name='v1.model.AgentConfiguration.document', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='document', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=837,
)


_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.AgentConfigurationDocument.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.AgentConfigurationDocument.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.AgentConfigurationDocument.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1578,
  serialized_end=1633,
)

_AGENTCONFIGURATIONDOCUMENT = _descriptor.Descriptor(
  name='AgentConfigurationDocument',
  full_name='v1.model.AgentConfigurationDocument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='v1.model.AgentConfigurationDocument.version', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.AgentConfigurationDocument.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tags', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='v1.model.AgentConfigurationDocument.telemetry', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='telemetry', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='v1.model.AgentConfigurationDocument.resources', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application', full_name='v1.model.AgentConfigurationDocument.application', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='application', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teleop', full_name='v1.model.AgentConfigurationDocument.teleop', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='teleop', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_forwarding', full_name='v1.model.AgentConfigurationDocument.port_forwarding', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='portForwarding', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blob_data', full_name='v1.model.AgentConfigurationDocument.blob_data', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='blobData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diagnostics', full_name='v1.model.AgentConfigurationDocument.diagnostics', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='diagnostics', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminal_access', full_name='v1.model.AgentConfigurationDocument.terminal_access', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='terminalAccess', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adapters', full_name='v1.model.AgentConfigurationDocument.adapters', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='adapters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtc_info', full_name='v1.model.AgentConfigurationDocument.rtc_info', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rtcInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=1633,
)


_ADAPTERCONFIGURATION = _descriptor.Descriptor(
  name='AdapterConfiguration',
  full_name='v1.model.AdapterConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.AdapterConfiguration.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.AdapterConfiguration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_id', full_name='v1.model.AdapterConfiguration.file_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_command', full_name='v1.model.AdapterConfiguration.exec_command', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='execCommand', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1635,
  serialized_end=1753,
)


_TELEOPCONFIGURATION = _descriptor.Descriptor(
  name='TeleopConfiguration',
  full_name='v1.model.TeleopConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ros_streams', full_name='v1.model.TeleopConfiguration.ros_streams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rosStreams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_streams', full_name='v1.model.TeleopConfiguration.custom_streams', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='customStreams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware_streams', full_name='v1.model.TeleopConfiguration.hardware_streams', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hardwareStreams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1756,
  serialized_end=2020,
)


_PORTFORWARDINGCONFIGURATION = _descriptor.Descriptor(
  name='PortForwardingConfiguration',
  full_name='v1.model.PortForwardingConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='v1.model.PortForwardingConfiguration.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2105,
)


_TELEOPROSSTREAMCONFIGURATION = _descriptor.Descriptor(
  name='TeleopRosStreamConfiguration',
  full_name='v1.model.TeleopRosStreamConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_name', full_name='v1.model.TeleopRosStreamConfiguration.topic_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_type', full_name='v1.model.TeleopRosStreamConfiguration.topic_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='v1.model.TeleopRosStreamConfiguration.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode_video', full_name='v1.model.TeleopRosStreamConfiguration.encode_video', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encodeVideo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_codec', full_name='v1.model.TeleopRosStreamConfiguration.audio_codec', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='audioCodec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='v1.model.TeleopRosStreamConfiguration.quality', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quality', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_reference_frame', full_name='v1.model.TeleopRosStreamConfiguration.base_reference_frame', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='baseReferenceFrame', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_frame', full_name='v1.model.TeleopRosStreamConfiguration.local_frame', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='localFrame', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2108,
  serialized_end=2443,
)


_TELEOPHARDWARESTREAMCONFIGURATION = _descriptor.Descriptor(
  name='TeleopHardwareStreamConfiguration',
  full_name='v1.model.TeleopHardwareStreamConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.TeleopHardwareStreamConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtc_stream_type', full_name='v1.model.TeleopHardwareStreamConfiguration.rtc_stream_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rtcStreamType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='v1.model.TeleopHardwareStreamConfiguration.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hw_descriptor', full_name='v1.model.TeleopHardwareStreamConfiguration.hw_descriptor', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hwDescriptor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='v1.model.TeleopHardwareStreamConfiguration.quality', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quality', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware_type', full_name='v1.model.TeleopHardwareStreamConfiguration.hardware_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hardwareType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtsp_encoding_needed', full_name='v1.model.TeleopHardwareStreamConfiguration.rtsp_encoding_needed', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rtspEncodingNeeded', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_onvif', full_name='v1.model.TeleopHardwareStreamConfiguration.is_onvif', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isOnvif', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_cam_username', full_name='v1.model.TeleopHardwareStreamConfiguration.ip_cam_username', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ipCamUsername', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_cam_password', full_name='v1.model.TeleopHardwareStreamConfiguration.ip_cam_password', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ipCamPassword', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2446,
  serialized_end=2840,
)


_TELEOPCUSTOMSTREAMCONFIGURATION = _descriptor.Descriptor(
  name='TeleopCustomStreamConfiguration',
  full_name='v1.model.TeleopCustomStreamConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.TeleopCustomStreamConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtc_stream_type', full_name='v1.model.TeleopCustomStreamConfiguration.rtc_stream_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rtcStreamType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='v1.model.TeleopCustomStreamConfiguration.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode_video', full_name='v1.model.TeleopCustomStreamConfiguration.encode_video', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encodeVideo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='v1.model.TeleopCustomStreamConfiguration.quality', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quality', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2843,
  serialized_end=3039,
)


_TELEMETRYCONFIGURATION = _descriptor.Descriptor(
  name='TelemetryConfiguration',
  full_name='v1.model.TelemetryConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streams', full_name='v1.model.TelemetryConfiguration.streams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ros', full_name='v1.model.TelemetryConfiguration.ros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ros', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3041,
  serialized_end=3168,
)


_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY = _descriptor.Descriptor(
  name='ConfigurationMapEntry',
  full_name='v1.model.ApplicationConfiguration.ConfigurationMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.ApplicationConfiguration.ConfigurationMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.ApplicationConfiguration.ConfigurationMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3302,
  serialized_end=3369,
)

_APPLICATIONCONFIGURATION = _descriptor.Descriptor(
  name='ApplicationConfiguration',
  full_name='v1.model.ApplicationConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration_map', full_name='v1.model.ApplicationConfiguration.configuration_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='configurationMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3171,
  serialized_end=3369,
)


_RESOURCESCONFIGURATION = _descriptor.Descriptor(
  name='ResourcesConfiguration',
  full_name='v1.model.ResourcesConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk', full_name='v1.model.ResourcesConfiguration.disk', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disk', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_throttle_hz', full_name='v1.model.ResourcesConfiguration.stream_throttle_hz', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamThrottleHz', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_bandwidth_agent', full_name='v1.model.ResourcesConfiguration.low_bandwidth_agent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lowBandwidthAgent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3372,
  serialized_end=3569,
)


_DISKCONFIGURATION = _descriptor.Descriptor(
  name='DiskConfiguration',
  full_name='v1.model.DiskConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buffer_size', full_name='v1.model.DiskConfiguration.buffer_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bufferSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand_buffer_size', full_name='v1.model.DiskConfiguration.on_demand_buffer_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onDemandBufferSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3571,
  serialized_end=3674,
)


_ROSCONFIGURATION = _descriptor.Descriptor(
  name='ROSConfiguration',
  full_name='v1.model.ROSConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_reference_frame_id', full_name='v1.model.ROSConfiguration.world_reference_frame_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='worldReferenceFrameId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3676,
  serialized_end=3751,
)


_STREAMCONFIGURATION_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.StreamConfiguration.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.StreamConfiguration.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.StreamConfiguration.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1578,
  serialized_end=1633,
)

_STREAMCONFIGURATION = _descriptor.Descriptor(
  name='StreamConfiguration',
  full_name='v1.model.StreamConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.StreamConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.StreamConfiguration.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tags', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ros_topic', full_name='v1.model.StreamConfiguration.ros_topic', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rosTopic', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ros_localization', full_name='v1.model.StreamConfiguration.ros_localization', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rosLocalization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directory_watch', full_name='v1.model.StreamConfiguration.directory_watch', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='directoryWatch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_tail', full_name='v1.model.StreamConfiguration.file_tail', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileTail', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ros_transform_tree', full_name='v1.model.StreamConfiguration.ros_transform_tree', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rosTransformTree', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='v1.model.StreamConfiguration.custom', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='custom', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='v1.model.StreamConfiguration.hardware', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hardware', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_hz', full_name='v1.model.StreamConfiguration.throttle_hz', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='throttleHz', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='v1.model.StreamConfiguration.disabled', index=10,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand', full_name='v1.model.StreamConfiguration.on_demand', index=11,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onDemand', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform', full_name='v1.model.StreamConfiguration.transform', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transform', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='v1.model.StreamConfiguration.quality', index=13,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quality', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMCONFIGURATION_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='configuration', full_name='v1.model.StreamConfiguration.configuration',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3754,
  serialized_end=4615,
)


_STREAMTRANSFORMCONFIGURATION = _descriptor.Descriptor(
  name='StreamTransformConfiguration',
  full_name='v1.model.StreamTransformConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='video_encoding_enabled', full_name='v1.model.StreamTransformConfiguration.video_encoding_enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='videoEncodingEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4617,
  serialized_end=4729,
)


_BLOBDATA = _descriptor.Descriptor(
  name='BlobData',
  full_name='v1.model.BlobData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='v1.model.BlobData.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4731,
  serialized_end=4761,
)


_DIAGNOSTICS = _descriptor.Descriptor(
  name='Diagnostics',
  full_name='v1.model.Diagnostics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='report_logs', full_name='v1.model.Diagnostics.report_logs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reportLogs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_metrics', full_name='v1.model.Diagnostics.report_metrics', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reportMetrics', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4764,
  serialized_end=4905,
)


_CUSTOM = _descriptor.Descriptor(
  name='Custom',
  full_name='v1.model.Custom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4907,
  serialized_end=4915,
)


_HARDWARE = _descriptor.Descriptor(
  name='Hardware',
  full_name='v1.model.Hardware',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hw_descriptor', full_name='v1.model.Hardware.hw_descriptor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hwDescriptor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_hw_descriptor', full_name='v1.model.Hardware.audio_hw_descriptor', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='audioHwDescriptor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware_type', full_name='v1.model.Hardware.hardware_type', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hardwareType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtsp_encoding_needed', full_name='v1.model.Hardware.rtsp_encoding_needed', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rtspEncodingNeeded', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_onvif', full_name='v1.model.Hardware.is_onvif', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isOnvif', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_cam_username', full_name='v1.model.Hardware.ip_cam_username', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ipCamUsername', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_cam_password', full_name='v1.model.Hardware.ip_cam_password', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ipCamPassword', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4918,
  serialized_end=5207,
)


_DIRECTORYWATCH = _descriptor.Descriptor(
  name='DirectoryWatch',
  full_name='v1.model.DirectoryWatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='directory', full_name='v1.model.DirectoryWatch.directory', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='directory', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension', full_name='v1.model.DirectoryWatch.extension', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extension', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='v1.model.DirectoryWatch.file_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_agent', full_name='v1.model.DirectoryWatch.remote_agent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='remoteAgent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5210,
  serialized_end=5370,
)


_FILETAIL = _descriptor.Descriptor(
  name='FileTail',
  full_name='v1.model.FileTail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='v1.model.FileTail.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='filename', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_format', full_name='v1.model.FileTail.file_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_key', full_name='v1.model.FileTail.time_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_format', full_name='v1.model.FileTail.time_format', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex', full_name='v1.model.FileTail.regex', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='regex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5373,
  serialized_end=5548,
)


_RTCINFO = _descriptor.Descriptor(
  name='RtcInfo',
  full_name='v1.model.RtcInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rtc_ice_transport_policies', full_name='v1.model.RtcInfo.rtc_ice_transport_policies', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rtcIceTransportPolicies', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtc_ice_server_protocol', full_name='v1.model.RtcInfo.rtc_ice_server_protocol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rtcIceServerProtocol', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_all_servers', full_name='v1.model.RtcInfo.use_all_servers', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='useAllServers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5551,
  serialized_end=5716,
)

_AGENTCONFIGURATIONSTORE.fields_by_name['configuration'].message_type = _AGENTCONFIGURATION
_AGENTCONFIGURATIONSTORE.fields_by_name['feature_set'].message_type = _AGENTFEATURESET
_AGENTCONFIGURATION.fields_by_name['document'].message_type = _AGENTCONFIGURATIONDOCUMENT
_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY.containing_type = _AGENTCONFIGURATIONDOCUMENT
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['tags'].message_type = _AGENTCONFIGURATIONDOCUMENT_TAGSENTRY
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['telemetry'].message_type = _TELEMETRYCONFIGURATION
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['resources'].message_type = _RESOURCESCONFIGURATION
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['application'].message_type = _APPLICATIONCONFIGURATION
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['teleop'].message_type = _TELEOPCONFIGURATION
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['port_forwarding'].message_type = _PORTFORWARDINGCONFIGURATION
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['blob_data'].message_type = _BLOBDATA
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['diagnostics'].message_type = _DIAGNOSTICS
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['terminal_access'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['adapters'].message_type = _ADAPTERCONFIGURATION
_AGENTCONFIGURATIONDOCUMENT.fields_by_name['rtc_info'].message_type = _RTCINFO
_TELEOPCONFIGURATION.fields_by_name['ros_streams'].message_type = _TELEOPROSSTREAMCONFIGURATION
_TELEOPCONFIGURATION.fields_by_name['custom_streams'].message_type = _TELEOPCUSTOMSTREAMCONFIGURATION
_TELEOPCONFIGURATION.fields_by_name['hardware_streams'].message_type = _TELEOPHARDWARESTREAMCONFIGURATION
_PORTFORWARDINGCONFIGURATION.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TELEOPROSSTREAMCONFIGURATION.fields_by_name['topic_type'].enum_type = protos_dot_model_dot_v1_dot_ros__pb2._ROSTOPICTYPE
_TELEOPROSSTREAMCONFIGURATION.fields_by_name['mode'].enum_type = _TELEOPMODE
_TELEOPHARDWARESTREAMCONFIGURATION.fields_by_name['mode'].enum_type = _TELEOPMODE
_TELEOPCUSTOMSTREAMCONFIGURATION.fields_by_name['mode'].enum_type = _TELEOPMODE
_TELEMETRYCONFIGURATION.fields_by_name['streams'].message_type = _STREAMCONFIGURATION
_TELEMETRYCONFIGURATION.fields_by_name['ros'].message_type = _ROSCONFIGURATION
_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY.containing_type = _APPLICATIONCONFIGURATION
_APPLICATIONCONFIGURATION.fields_by_name['configuration_map'].message_type = _APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY
_RESOURCESCONFIGURATION.fields_by_name['disk'].message_type = _DISKCONFIGURATION
_RESOURCESCONFIGURATION.fields_by_name['stream_throttle_hz'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_STREAMCONFIGURATION_TAGSENTRY.containing_type = _STREAMCONFIGURATION
_STREAMCONFIGURATION.fields_by_name['tags'].message_type = _STREAMCONFIGURATION_TAGSENTRY
_STREAMCONFIGURATION.fields_by_name['ros_topic'].message_type = protos_dot_model_dot_v1_dot_ros__pb2._ROSTOPIC
_STREAMCONFIGURATION.fields_by_name['ros_localization'].message_type = protos_dot_model_dot_v1_dot_ros__pb2._ROSLOCALIZATION
_STREAMCONFIGURATION.fields_by_name['directory_watch'].message_type = _DIRECTORYWATCH
_STREAMCONFIGURATION.fields_by_name['file_tail'].message_type = _FILETAIL
_STREAMCONFIGURATION.fields_by_name['ros_transform_tree'].message_type = protos_dot_model_dot_v1_dot_ros__pb2._ROSTRANSFORMTREE
_STREAMCONFIGURATION.fields_by_name['custom'].message_type = _CUSTOM
_STREAMCONFIGURATION.fields_by_name['hardware'].message_type = _HARDWARE
_STREAMCONFIGURATION.fields_by_name['throttle_hz'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_STREAMCONFIGURATION.fields_by_name['disabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_STREAMCONFIGURATION.fields_by_name['on_demand'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_STREAMCONFIGURATION.fields_by_name['transform'].message_type = _STREAMTRANSFORMCONFIGURATION
_STREAMCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _STREAMCONFIGURATION.fields_by_name['ros_topic'])
_STREAMCONFIGURATION.fields_by_name['ros_topic'].containing_oneof = _STREAMCONFIGURATION.oneofs_by_name['configuration']
_STREAMCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _STREAMCONFIGURATION.fields_by_name['ros_localization'])
_STREAMCONFIGURATION.fields_by_name['ros_localization'].containing_oneof = _STREAMCONFIGURATION.oneofs_by_name['configuration']
_STREAMCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _STREAMCONFIGURATION.fields_by_name['directory_watch'])
_STREAMCONFIGURATION.fields_by_name['directory_watch'].containing_oneof = _STREAMCONFIGURATION.oneofs_by_name['configuration']
_STREAMCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _STREAMCONFIGURATION.fields_by_name['file_tail'])
_STREAMCONFIGURATION.fields_by_name['file_tail'].containing_oneof = _STREAMCONFIGURATION.oneofs_by_name['configuration']
_STREAMCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _STREAMCONFIGURATION.fields_by_name['ros_transform_tree'])
_STREAMCONFIGURATION.fields_by_name['ros_transform_tree'].containing_oneof = _STREAMCONFIGURATION.oneofs_by_name['configuration']
_STREAMCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _STREAMCONFIGURATION.fields_by_name['custom'])
_STREAMCONFIGURATION.fields_by_name['custom'].containing_oneof = _STREAMCONFIGURATION.oneofs_by_name['configuration']
_STREAMCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _STREAMCONFIGURATION.fields_by_name['hardware'])
_STREAMCONFIGURATION.fields_by_name['hardware'].containing_oneof = _STREAMCONFIGURATION.oneofs_by_name['configuration']
_STREAMTRANSFORMCONFIGURATION.fields_by_name['video_encoding_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DIAGNOSTICS.fields_by_name['report_logs'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DIAGNOSTICS.fields_by_name['report_metrics'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DIRECTORYWATCH.fields_by_name['file_type'].enum_type = _FILETYPE
_FILETAIL.fields_by_name['file_format'].enum_type = _FILEFORMAT
DESCRIPTOR.message_types_by_name['AgentConfigurationStore'] = _AGENTCONFIGURATIONSTORE
DESCRIPTOR.message_types_by_name['AgentFeatureSet'] = _AGENTFEATURESET
DESCRIPTOR.message_types_by_name['AgentConfiguration'] = _AGENTCONFIGURATION
DESCRIPTOR.message_types_by_name['AgentConfigurationDocument'] = _AGENTCONFIGURATIONDOCUMENT
DESCRIPTOR.message_types_by_name['AdapterConfiguration'] = _ADAPTERCONFIGURATION
DESCRIPTOR.message_types_by_name['TeleopConfiguration'] = _TELEOPCONFIGURATION
DESCRIPTOR.message_types_by_name['PortForwardingConfiguration'] = _PORTFORWARDINGCONFIGURATION
DESCRIPTOR.message_types_by_name['TeleopRosStreamConfiguration'] = _TELEOPROSSTREAMCONFIGURATION
DESCRIPTOR.message_types_by_name['TeleopHardwareStreamConfiguration'] = _TELEOPHARDWARESTREAMCONFIGURATION
DESCRIPTOR.message_types_by_name['TeleopCustomStreamConfiguration'] = _TELEOPCUSTOMSTREAMCONFIGURATION
DESCRIPTOR.message_types_by_name['TelemetryConfiguration'] = _TELEMETRYCONFIGURATION
DESCRIPTOR.message_types_by_name['ApplicationConfiguration'] = _APPLICATIONCONFIGURATION
DESCRIPTOR.message_types_by_name['ResourcesConfiguration'] = _RESOURCESCONFIGURATION
DESCRIPTOR.message_types_by_name['DiskConfiguration'] = _DISKCONFIGURATION
DESCRIPTOR.message_types_by_name['ROSConfiguration'] = _ROSCONFIGURATION
DESCRIPTOR.message_types_by_name['StreamConfiguration'] = _STREAMCONFIGURATION
DESCRIPTOR.message_types_by_name['StreamTransformConfiguration'] = _STREAMTRANSFORMCONFIGURATION
DESCRIPTOR.message_types_by_name['BlobData'] = _BLOBDATA
DESCRIPTOR.message_types_by_name['Diagnostics'] = _DIAGNOSTICS
DESCRIPTOR.message_types_by_name['Custom'] = _CUSTOM
DESCRIPTOR.message_types_by_name['Hardware'] = _HARDWARE
DESCRIPTOR.message_types_by_name['DirectoryWatch'] = _DIRECTORYWATCH
DESCRIPTOR.message_types_by_name['FileTail'] = _FILETAIL
DESCRIPTOR.message_types_by_name['RtcInfo'] = _RTCINFO
DESCRIPTOR.enum_types_by_name['TeleopMode'] = _TELEOPMODE
DESCRIPTOR.enum_types_by_name['FileFormat'] = _FILEFORMAT
DESCRIPTOR.enum_types_by_name['FileType'] = _FILETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AgentConfigurationStore = _reflection.GeneratedProtocolMessageType('AgentConfigurationStore', (_message.Message,), {
  'DESCRIPTOR' : _AGENTCONFIGURATIONSTORE,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AgentConfigurationStore)
  })
_sym_db.RegisterMessage(AgentConfigurationStore)

AgentFeatureSet = _reflection.GeneratedProtocolMessageType('AgentFeatureSet', (_message.Message,), {
  'DESCRIPTOR' : _AGENTFEATURESET,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AgentFeatureSet)
  })
_sym_db.RegisterMessage(AgentFeatureSet)

AgentConfiguration = _reflection.GeneratedProtocolMessageType('AgentConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AGENTCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AgentConfiguration)
  })
_sym_db.RegisterMessage(AgentConfiguration)

AgentConfigurationDocument = _reflection.GeneratedProtocolMessageType('AgentConfigurationDocument', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _AGENTCONFIGURATIONDOCUMENT_TAGSENTRY,
    '__module__' : 'protos.model.v1.config_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.AgentConfigurationDocument.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _AGENTCONFIGURATIONDOCUMENT,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AgentConfigurationDocument)
  })
_sym_db.RegisterMessage(AgentConfigurationDocument)
_sym_db.RegisterMessage(AgentConfigurationDocument.TagsEntry)

AdapterConfiguration = _reflection.GeneratedProtocolMessageType('AdapterConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTERCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AdapterConfiguration)
  })
_sym_db.RegisterMessage(AdapterConfiguration)

TeleopConfiguration = _reflection.GeneratedProtocolMessageType('TeleopConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.TeleopConfiguration)
  })
_sym_db.RegisterMessage(TeleopConfiguration)

PortForwardingConfiguration = _reflection.GeneratedProtocolMessageType('PortForwardingConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _PORTFORWARDINGCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.PortForwardingConfiguration)
  })
_sym_db.RegisterMessage(PortForwardingConfiguration)

TeleopRosStreamConfiguration = _reflection.GeneratedProtocolMessageType('TeleopRosStreamConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPROSSTREAMCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.TeleopRosStreamConfiguration)
  })
_sym_db.RegisterMessage(TeleopRosStreamConfiguration)

TeleopHardwareStreamConfiguration = _reflection.GeneratedProtocolMessageType('TeleopHardwareStreamConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPHARDWARESTREAMCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.TeleopHardwareStreamConfiguration)
  })
_sym_db.RegisterMessage(TeleopHardwareStreamConfiguration)

TeleopCustomStreamConfiguration = _reflection.GeneratedProtocolMessageType('TeleopCustomStreamConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPCUSTOMSTREAMCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.TeleopCustomStreamConfiguration)
  })
_sym_db.RegisterMessage(TeleopCustomStreamConfiguration)

TelemetryConfiguration = _reflection.GeneratedProtocolMessageType('TelemetryConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _TELEMETRYCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.TelemetryConfiguration)
  })
_sym_db.RegisterMessage(TelemetryConfiguration)

ApplicationConfiguration = _reflection.GeneratedProtocolMessageType('ApplicationConfiguration', (_message.Message,), {

  'ConfigurationMapEntry' : _reflection.GeneratedProtocolMessageType('ConfigurationMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY,
    '__module__' : 'protos.model.v1.config_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.ApplicationConfiguration.ConfigurationMapEntry)
    })
  ,
  'DESCRIPTOR' : _APPLICATIONCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ApplicationConfiguration)
  })
_sym_db.RegisterMessage(ApplicationConfiguration)
_sym_db.RegisterMessage(ApplicationConfiguration.ConfigurationMapEntry)

ResourcesConfiguration = _reflection.GeneratedProtocolMessageType('ResourcesConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ResourcesConfiguration)
  })
_sym_db.RegisterMessage(ResourcesConfiguration)

DiskConfiguration = _reflection.GeneratedProtocolMessageType('DiskConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _DISKCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.DiskConfiguration)
  })
_sym_db.RegisterMessage(DiskConfiguration)

ROSConfiguration = _reflection.GeneratedProtocolMessageType('ROSConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ROSCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ROSConfiguration)
  })
_sym_db.RegisterMessage(ROSConfiguration)

StreamConfiguration = _reflection.GeneratedProtocolMessageType('StreamConfiguration', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STREAMCONFIGURATION_TAGSENTRY,
    '__module__' : 'protos.model.v1.config_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.StreamConfiguration.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _STREAMCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.StreamConfiguration)
  })
_sym_db.RegisterMessage(StreamConfiguration)
_sym_db.RegisterMessage(StreamConfiguration.TagsEntry)

StreamTransformConfiguration = _reflection.GeneratedProtocolMessageType('StreamTransformConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRANSFORMCONFIGURATION,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.StreamTransformConfiguration)
  })
_sym_db.RegisterMessage(StreamTransformConfiguration)

BlobData = _reflection.GeneratedProtocolMessageType('BlobData', (_message.Message,), {
  'DESCRIPTOR' : _BLOBDATA,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.BlobData)
  })
_sym_db.RegisterMessage(BlobData)

Diagnostics = _reflection.GeneratedProtocolMessageType('Diagnostics', (_message.Message,), {
  'DESCRIPTOR' : _DIAGNOSTICS,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Diagnostics)
  })
_sym_db.RegisterMessage(Diagnostics)

Custom = _reflection.GeneratedProtocolMessageType('Custom', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOM,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Custom)
  })
_sym_db.RegisterMessage(Custom)

Hardware = _reflection.GeneratedProtocolMessageType('Hardware', (_message.Message,), {
  'DESCRIPTOR' : _HARDWARE,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Hardware)
  })
_sym_db.RegisterMessage(Hardware)

DirectoryWatch = _reflection.GeneratedProtocolMessageType('DirectoryWatch', (_message.Message,), {
  'DESCRIPTOR' : _DIRECTORYWATCH,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.DirectoryWatch)
  })
_sym_db.RegisterMessage(DirectoryWatch)

FileTail = _reflection.GeneratedProtocolMessageType('FileTail', (_message.Message,), {
  'DESCRIPTOR' : _FILETAIL,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.FileTail)
  })
_sym_db.RegisterMessage(FileTail)

RtcInfo = _reflection.GeneratedProtocolMessageType('RtcInfo', (_message.Message,), {
  'DESCRIPTOR' : _RTCINFO,
  '__module__' : 'protos.model.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.RtcInfo)
  })
_sym_db.RegisterMessage(RtcInfo)


DESCRIPTOR._options = None
_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY._options = None
_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY._options = None
_STREAMCONFIGURATION_TAGSENTRY._options = None
# @@protoc_insertion_point(module_scope)



from formant.sdk.agent.v1.localization.utils import get_quaternion_from_euler
from formant.protos.model.v1 import math_pb2
from formant.sdk.agent.v1.localization.utils import validate_type, get_ros_module


class Quaternion:
    @classmethod
    def from_ros(cls, quaternion):
        msgs = get_ros_module("geometry_msgs.msg")
        validate_type(quaternion, msgs.Quaternion)
        return cls(quaternion.x, quaternion.y, quaternion.z, quaternion.w)

    @classmethod
    def from_direction(
        cls, direction  # type: float
    ):
        return cls.from_euler(0, 0, direction)

    @classmethod
    def from_euler(
        cls,
        roll,  # type: float
        pitch,  # type: float
        yaw,  # type: float
    ):
        [x, y, z, w] = get_quaternion_from_euler(roll, pitch, yaw)
        return cls(x, y, z, w)

    @classmethod
    def identity(cls):
        return cls(0, 0, 0, 1)

    def __init__(
        self,
        x,  # type: float
        y,  # type: float
        z,  # type: float
        w,  # type: float
    ):
        self.x = x
        self.y = y
        self.z = z
        self.w = w

    def to_proto(self):
        return math_pb2.Quaternion(x=self.x, y=self.y, z=self.z, w=self.w)



import numpy as np
import importlib


# TODO: improve error log
def validate_type(o, t):
    if not isinstance(o, t):
        raise Exception("object %s is not of type %s" % (type(o), type(t())))


def get_ros_module(module_name):
    try:
        return importlib.import_module(module_name)
    except ModuleNotFoundError as e:
        raise Exception("ROS not intalled, could not find module: %s" % e)


def zero_twist(twist):
    zero_vector3(twist.linear)
    zero_vector3(twist.angular)


def zero_transform(transform):
    zero_vector3(transform.translation)
    zero_quanternion(transform.rotation)


def zero_quanternion(quanternion):
    quanternion.x = 0
    quanternion.y = 0
    quanternion.z = 0
    quanternion.w = 1


def zero_vector3(vector3):
    vector3.x = 0
    vector3.y = 0
    vector3.z = 0


def get_quaternion_from_euler(roll, pitch, yaw):
    """
    Convert an Euler angle to a quaternion.

    Input
        :param roll: The roll (rotation around x-axis) angle in radians.
        :param pitch: The pitch (rotation around y-axis) angle in radians.
        :param yaw: The yaw (rotation around z-axis) angle in radians.

    Output
        :return qx, qy, qz, qw: The orientation in quaternion [x,y,z,w] format
    """
    qx = np.sin(roll / 2) * np.cos(pitch / 2) * np.cos(yaw / 2) - np.cos(
        roll / 2
    ) * np.sin(pitch / 2) * np.sin(yaw / 2)
    qy = np.cos(roll / 2) * np.sin(pitch / 2) * np.cos(yaw / 2) + np.sin(
        roll / 2
    ) * np.cos(pitch / 2) * np.sin(yaw / 2)
    qz = np.cos(roll / 2) * np.cos(pitch / 2) * np.sin(yaw / 2) - np.sin(
        roll / 2
    ) * np.sin(pitch / 2) * np.cos(yaw / 2)
    qw = np.cos(roll / 2) * np.cos(pitch / 2) * np.cos(yaw / 2) + np.sin(
        roll / 2
    ) * np.sin(pitch / 2) * np.sin(yaw / 2)

    return [qx, qy, qz, qw]
